@@ -7,35 +7,34 @@ Net::Google::Spelling - simple OOP-ish interface to the Google SOAP API for spel
 =head1 SYNOPSIS
 
  use Net::Google::Spelling;
- my $spelling = Net::Google::Spelling($service,\%args);
+ my $spelling = Net::Google::Spelling(\%args);
 
  $spelling->phrase("muntreal qweebec");
  print $spelling->suggest()."\n";
 
 =head1 DESCRIPTION
 
-Provides a simple OOP-ish interface to the Google SOAP API for spelling suggestions.
+Provides a simple OOP-ish interface to the Google SOAP API for
+spelling suggestions.
 
 This package is used by I<Net::Google>.
 
 =cut
 
-package Net::Google::Spelling;
 use strict;
 
+package Net::Google::Spelling;
+use base qw (Net::Google::tool);
+
 use Carp;
-use Exporter;
 
-$Net::Google::Spelling::VERSION   = '0.14';
-@Net::Google::Spelling::ISA       = qw (Exporter);
-@Net::Google::Spelling::EXPORT    = qw ();
-@Net::Google::Spelling::EXPORT_OK = qw ();
+$Net::Google::Spelling::VERSION   = '0.2';
 
-=head1 Class Methods
+=head1 PACKAGE METHODS
 
-=head2 $pkg = Net::Google::Spelling->new($service,\%args)
+=cut
 
-Where I<$service> is a valid I<GoogleSearchService> object.
+=head2 $pkg = __PACKAGE__->new(\%args)
 
 Valid arguments are :
 
@@ -45,21 +44,61 @@ Valid arguments are :
 
 B<key>
 
-String. Google API key. If none is provided then the key passed to the parent I<Net::Google> object will be used.
+I<string>.A Google API key.
+
+If none is provided then the key passed to the parent I<Net::Google>
+object will be used.
 
 =item *
 
 B<phrase>
 
-String or array reference.
+I<string> or I<array reference>.
+
+=item *
+
+B<http_proxy>
+
+I<url>. A URL for proxy-ing HTTP requests.
+
+=item *
+
+B<debug>
+
+Valid options are:
+
+=over 4
+
+=item *
+
+I<boolean>
+
+If true prints debugging information returned by SOAP::Lite
+to STDERR
+
+=item *
+
+I<coderef>.
+
+Your own subroutine for munging the debugging information
+returned by SOAP::Lite.
 
 =back
 
+=back
+
+The object constructor in Net::Google 0.53, and earlier, expected
+a I<GoogleSearchService> object as its first argument followed by
+ a hash reference of argument. Versions 0.6 and higher are backwards 
+compatible.
+
+Returns an object. Woot!
+
 =cut
 
 sub new {
   my $pkg = shift;
-  
+
   my $self = {};
   bless $self,$pkg;
 
@@ -72,22 +111,11 @@ sub new {
 
 sub init {
   my $self    = shift;
-  my $service = shift;
-  my $args    = shift;
 
-  if (ref($service) ne "GoogleSearchService") {
-    carp "Unknown service";
-    return 0;
-  }
+  my $args = $self->SUPER::init("spelling",@_)
+    || return 0;
 
-  $self->{'_service'}  = $service;
-
-  if (! $args->{'key'}) {
-    carp "You must define a key";
-    return 0;
-  }
-
-  $self->key($args->{'key'});
+  #
 
   if ($args->{'phrase'}) {
     defined($self->phrase( (ref($args->{'phrase'}) eq "ARRAY") ? @{$args->{'phrase'}} : $args->{'phrase'} )) || return 0;
@@ -96,28 +124,34 @@ sub init {
   return 1;
 }
 
-=head2 $pkg->key($key)
-
-Returns a string. Returns undef if there was an error.
+=head1 OBJECT METHODS
 
 =cut
 
-sub key {
-  my $self = shift;
-  my $key  = shift;
+=head2 $obj->key($string)
 
-  if (defined($key)) {
-    $self->{'_key'} = $key;
-  }
+Get/set the Google API key for this object.
 
-  return $self->{'_key'};
-}
+=cut
 
-=head2 $pkg->phrase(@words)
+# Defined in Net::Google::tool
+
+=head2 $obj->http_proxy($url)
+
+Get/set the HTTP proxy for this object.
+
+Returns a string.
+
+=cut
+
+# Defined in Net::Google::tool
+
+=head2 $obj->phrase(@words)
 
 Add one or more words to the phrase you want to spell-check.
 
-If the first item in I<@words> is empty, then any existing I<phrase> data will be removed before the new data is added.
+If the first item in I<@words> is empty, then any existing I<phrase> 
+data will be removed before the new data is added.
 
 Returns a string. Returns undef if there was an error.
 
@@ -138,7 +172,7 @@ sub phrase {
   return join("",@{$self->{'_phrase'}});
 }
 
-=head2 $pkg->suggest()
+=head2 $obj->suggest()
 
 Fetch the spelling suggestion from the Google servers.
 
@@ -156,11 +190,11 @@ sub suggest {
 
 =head1 VERSION
 
-0.14
+0.2
 
 =head1 DATE
 
-$Date: 2003/02/22 16:48:52 $
+$Date: 2003/03/10 14:20:19 $
 
 =head1 AUTHOR
 
@@ -174,7 +208,8 @@ L<Net::Google>
 
 Copyright (c) 2002-2003, Aaron Straup Cope. All Rights Reserved.
 
-This is free software, you may use it and distribute it under the same terms as Perl itself.
+This is free software, you may use it and distribute it under the same 
+terms as Perl itself.
 
 =cut
 
